#
# spec file for package soapy-remote
#
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define soapy_modver 0.6
%define soapy_modname soapysdr%{soapy_modver}-module-remote

Name:           soapy-remote
Version:        0.4.2
Release:        lp150.1.3
Summary:        Use any Soapy SDR remotely 
License:        BSL-1.0
Group:          Productivity/Hamradio/Other
Url:            https://github.com/pothosware/SoapyRemote/wiki
#Git-Clone:     https://github.com/pothosware/SoapyRemote.git
Source:         https://github.com/pothosware/SoapyRemote/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(SoapySDR)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Soapy Remote - Remote device support for Soapy SDR.
A Soapy module that supports remote devices within the Soapy API.

%package -n %{soapy_modname}
Summary:        Use any Soapy SDR remotely
Group:          System/Libraries

%description -n %{soapy_modname}
Soapy Remote - Remote device support for Soapy SDR.
A Soapy module that supports remote devices within the Soapy API.

%prep
%setup -q -n SoapyRemote-%{name}-%{version}

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install
# FIXME: should be handled - disabled for now
rm %{buildroot}//usr/lib/sysctl.d/SoapySDRServer.conf
rm %{buildroot}//usr/lib/systemd/system/SoapySDRServer.service

%files -n %{soapy_modname}
%defattr(-,root,root)
%doc LICENSE_1_0.txt README.md
%{_bindir}/SoapySDRServer
%{_mandir}/man1/SoapySDRServer.1%{ext_man}
%dir %{_libdir}/SoapySDR/
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libremoteSupport.so

%changelog
* Tue Aug  1 2017 mardnh@gmx.de
- Update to version 0.4.1
  + Fixed timeout problem in log acceptor receiver loop
  + Added server check for slow calls and longer timeout
  - This also resolves timeout errors for lengthy calls
  + Added network-online.target for systemd service script
* Fri Jun  9 2017 mardnh@gmx.de
- Update to version 0.4.1
  + Added timeout for logger connect and control unpacker
  + Fixed error log formatting in the client log acceptor
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.4.0
  + Added support for frequency corrections for fine adjustments
  + Added support forgetSampleRateRange() for continuous ranges
  + Added support for CF32 local format with CS12 remote format
  + Added support for CS16 local format with CS12 remote format
  + Added support for CS16 local format with CS8 remote format
  + readStream thread support for SOAPY_SDR_END_ABRUPT flag
  + readStream thread apply second SOAPY_SDR_END_BURST flag
  + Added timeout to socket connect and factory calls
  + Support range with step size (backwards compatible)
  + Added tcp support for streaming via remote:prot=tcp
  + Support for bulk register read/write interface APIs
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Fri Apr 14 2017 mardnh@gmx.de
- Update to version 0.3.2 (tagged release)
- renamed package from SoapyRemote to soapy-remote
- specfile cleanup
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.1.0.git1448155900.71f7183:
  + remote: support apis to query agc and clock rates
  + remote: sockaddr class and sento/recvfrom
  + soapy: move url utils into class
  + soapy: forward declare thread in headers
  + soapy: set errno on lookup failure
  + soapy: work on ssdp multicast discovery
  + soapy: moved several calls into info utils
  + soapy: common endpoint class for SSDP
  + remote: should be mostly working now
  + remote: cleanup and search/notify asap
  + remote: generate and reuse type 1 UUID for server
  + remote: fixing up uuid implementation
  + remote: constants for the SSDP connection
  + remote: fix socket calls for msvc types
  + remote: SSDP endpoint reference counted singleton
  + remote: v6 multicast fixes and scoped addresses
  + remote: fixes for compiling on OSX
  + remote: fix issue with the forward declares (osx)
  + soapy: SO_REUSEPORT for osx when using multicast
  + remote: send multicast notification for msearch as well
  + remote: logger prints, and common header handler
  + remote: constants for notify alive and byebye
  + remote: client-side arg info calls implemented
  + remote: server-side handling for new info calls
  + remote: support native format in stream calls
  + remote: added new call support to changelog
  + remote: blacklist for failed groups
  + remote: hold a static instance in the client
  + remote: fix lock scope in getStreamArgsInfo()
  + remote: added entry to changelog for SSDP
  + remote: improve error reporting in socket wrapper
  + remote: fix error reporting for other socket calls
  + remote: same reporting for setting buffer size
  + remote: matching error reporting in endpoint
  + remote: osx manual interface selection work-around
  + remote: debug prints for getDefaultIfaceIndex()
  + remote: automatic stream close on SOAPY_REMOTE_UNMAKE
  + remote: default interface filter on ipv6 as well
  + remote: improved logging and socket buffer resize calls
  + remote: fix formatToSize for complex-12bit
  + remote: Support CU8 native conversion to CF32
  + remote: Use formatToSize() from SoapySDR library
  + travis: created a travis ci config for soapy remote
  + travis: added travis build status to readme
  + travis: unit check that driver loads
  + remote: support VC11 by using isspace instead
* Mon Oct 12 2015 mardnh@gmx.de
- initial package
